--[[
The Icarus Project, Copyright (c) 2005 John Forsythe <chaosmachine@gmail.com> (aka chaosmachine)
Feel free to learn and borrow from this code for non-commercial purposes.
If you use my code in your project, I'd appreciate a credit in your readme file.
]]

function updateScreen(noText)
	screen:blit(0, 0, background, 0, 0, 480, 272, false)
	screen:blit(0, 0, blockImage)
	if not noText then
		if moveMode == true then drawGrabbed() end
		if moveMode == false then drawCursor() end
		screen:print(8,4, "Level " .. level, colorWhite)
		screen:print(408,262, "" .. secondsToTime(levelSeconds()), colorWhite)
	end
	screen.waitVblankStart()
	screen.flip()
	if (not Music.playing()) and musicOn then
		nextSong()
	end
		
end

function drawTileToBackgroundImage(tile, x, y)
	background:blit(16*x+(8*xOffset), 16*y+(8*yOffset), tiles, 16*tile.x, 16*tile.y, 16, 16)
end	

function drawTileToBlockImage(tile, x, y)
	blockImage:blit(16*x+(8*xOffset), 16*y+(8*yOffset), tiles, 16*tile.x, 16*tile.y, 16, 16)
end	

function drawTileToOffscreen(tile, x, y)
	screen:blit(16*x+(8*xOffset), 16*y+(8*yOffset), tiles, 16*tile.x, 16*tile.y, 16, 16)
end

function drawCursor()
	drawTileToOffscreen(getTile("cursor"), cursor.x, cursor.y)
end

function updateBlockImage()
	-- this redraws all blocks that are not grabbed
	blockImage:clear()
	for i,aPiece in ipairs(piece) do
		if i ~= grabbed then
			for ii,aBlock in ipairs(aPiece) do
				drawTileToBlockImage(aBlock.tile, aPiece.x + aBlock.x, aPiece.y + aBlock.y)
			end
		end
	end
end

function drawGrabbed()
	for ii,aBlock in ipairs(piece[grabbed]) do
		drawTileToOffscreen(getTile(aBlock.bType,"grabby"), piece[grabbed].x + aBlock.x, piece[grabbed].y + aBlock.y)
	end	
end

function drawBorder()
	for i,aBorder in ipairs(border) do
		drawTileToBackgroundImage(getTile(aBorder.bType,"border"), border.x + aBorder.x, border.y + aBorder.y)
	end
end

function drawGoal()
	for i,aGoal in ipairs(goal) do
		drawTileToBackgroundImage(getTile("goal"), border.x + aGoal.x, border.y + aGoal.y)
	end
end

function drawToTiles(destX, destY, sourceX, sourceY, rotate)
	if rotate == 0 then
		tiles:blit(16*destX, 16*destY, sourceTiles, 16*sourceX, 16*sourceY, 16, 16)
	elseif rotate == 1 then
 		for r=1,rotate do
			for x=0,15 do
				for y=0,15 do
					tiles:pixel((destX*16)+(16-y-1), (destY*16)+x, sourceTiles:pixel(16*sourceX+x,16*sourceY+y))
 				end
			end
		end
	elseif rotate==2 then
	 	for r=1,rotate do
			for x=0,15 do
				for y=0,15 do
					tiles:pixel((destX*16)+(16-x-1), (destY*16)+(16-y-1), sourceTiles:pixel(16*sourceX+x,16*sourceY+y))
 				end
			end
		end
	elseif rotate==3 then
	 	for r=1,rotate do
			for x=0,15 do
				for y=0,15 do
					tiles:pixel((destX*16)+y, (destY*16)+(16-x-1), sourceTiles:pixel(16*sourceX+x,16*sourceY+y))
 				end
			end
		end
	end
end


function doP(dx,dy)
	tiles:pixel(dx, dy, colorWhite)
end

function outlineText(x, y, text, foreColor, backColor)
	screen:print(x-1, y-1, text, backColor)
	screen:print(x-1, y, text, backColor)
	screen:print(x-1, y+1, text, backColor)
	screen:print(x, y-1, text, backColor)
	screen:print(x, y+1, text, backColor)
	screen:print(x+1, y-1, text, backColor)
	screen:print(x+1, y, text, backColor)
	screen:print(x+1, y+1, text, backColor)
	screen:print(x, y, text, foreColor)
end

function fadeOut(start)
	local fader = Image.createEmpty(480, 272)	
	for i=start or 15,136 do
		fader:fillRect(0,i,480,1, colorWhite)
		fader:fillRect(0,271-i,480,1, colorWhite)
		screen:blit(0,0,fader)
		screen.flip()
		screen.waitVblankStart()
		fader:fillRect(0,i,480,1, colorBlack)
		fader:fillRect(0,271-i,480,1, colorBlack)
	end
	screen:blit(0,0,fader)
	screen.flip()
	screen.waitVblankStart()
end

function fadeIn()
	fader = Image.createEmpty(480, 272)	
	fader:fillRect(0,0,480,272, colorBlack)
	for i=136,16,-1 do
		fader:fillRect(0,i,480,1, colorWhite)
		fader:fillRect(0,271-i,480,1, colorWhite)
		screen:blit(0, 0, background, 0, 0, 480, 272, false)
		screen:blit(0, 0, blockImage)	
		screen:blit(0,0,fader)
		screen.flip()
		screen.waitVblankStart()
		fader:fillRect(0,i,480,1)
		fader:fillRect(0,271-i,480,1)
	end
	fader:fillRect(0,15,480,1, colorWhite)
	fader:fillRect(0,271-15,480,1, colorWhite)
	screen:blit(0,0,fader)
	screen.flip()
	screen.waitVblankStart()
end



